.. currentmodule:: wildboar

###################
Supervised learning
###################


In supervised learning, we are given a collection of labeled time series and the
goal is to produce an estimator that as accurately as possible can map
previously unseen time series to the correct label.

.. toctree::
   :maxdepth: 2
   :hidden:

   supervised/trees
   supervised/ensemble
   supervised/transform
